==> kzEvents-0_1_0.zip: kzEvents/sample.php <==
<?php

# Copiez-coller ce fichier dans l'édition d'une page statique
# Dans le contexte de l'édition d'une page statique, $this représente $plxShow.

# Filtrer et trier $this->plxMotor->aEvents
$events = $this->plxMotor->aEvents;
$this->plxMotor->motif = '#^(?:' . implode('|', array_keys($events)) . ').#';
$this->plxMotor->getArticles();

while($this->plxMotor->plxRecord_arts->loop()) {
  $dateEvent = $events[$this->plxMotor->plxRecord_arts->f('numero')]['kzEvent'];
?>
				<article class="article" id="post-<?php echo $this->artId(); ?>">
						<header>
							<span class="art-date">
								<time datetime="<?= $dateEvent ?>">
									<?= plxDate::formatDate(str_replace('-', '', $dateEvent) , '#num_day #month #num_year(4)'); ?>
								</time>
							</span>
							<span class="art-date">
								<time datetime="<?php $this->artDate('#num_year(4)-#num_month-#num_day'); ?>">
									<?php $this->artDate('#num_day #month #num_year(4)'); ?>
								</time>
							</span>
							<h2>
								<?php $this->artTitle('link'); ?>
							</h2>
							<div>
								<small>
									<span class="written-by">
										<?php $this->lang('WRITTEN_BY'); ?> <?php $this->artAuthor() ?>
									</span>
									<span class="art-nb-com">
										<?php $this->artNbCom(); ?>
									</span>
								</small>
							</div>
							<div>
								<small>
									<span class="classified-in">
										<?php $this->lang('CLASSIFIED_IN') ?> : <?php $this->artCat() ?>
									</span>
									<span class="tags">
										<?php $this->lang('TAGS') ?> : <?php $this->artTags() ?>
									</span>
								</small>
							</div>
						</header>
						<?php $this->artThumbnail(); ?>
						<?php $this->artChapo(); ?>
					</article>
<?php
}
?>

==> kzEvents-0_1_1.zip: kzEvents/sample.php <==
<?php

# Copiez-coller ce fichier dans l'édition d'une page statique
# Dans le contexte de l'édition d'une page statique, $this représente $plxShow.

# Filtrer $this->plxMotor->aEvents
$events = $this->plxMotor->aEvents;
$this->plxMotor->motif = '#^(?:' . implode('|', array_keys($events)) . ').#';
$this->plxMotor->getArticles('all');

# On retrie les articles selon les dates d'évènements
usort($this->plxMotor->plxRecord_arts->result, function($a, $b) {
    return strcmp($a['kzEvent'], $b['kzEvent']);
});


while($this->plxMotor->plxRecord_arts->loop()) {
  $dateEvent = $events[$this->plxMotor->plxRecord_arts->f('numero')]['kzEvent'];
?>
				<article class="article" id="post-<?php echo $this->artId(); ?>">
						<header>
							<span class="art-date">
								<time datetime="<?= $dateEvent ?>">
									<?= plxDate::formatDate(str_replace('-', '', $dateEvent) , '#num_day #month #num_year(4)'); ?>
								</time>
							</span>
							<span class="art-date">
								<time datetime="<?php $this->artDate('#num_year(4)-#num_month-#num_day'); ?>">
									<?php $this->artDate('#num_day #month #num_year(4)'); ?>
								</time>
							</span>
							<h2>
								<?php $this->artTitle('link'); ?>
							</h2>
							<div>
								<small>
									<span class="written-by">
										<?php $this->lang('WRITTEN_BY'); ?> <?php $this->artAuthor() ?>
									</span>
									<span class="art-nb-com">
										<?php $this->artNbCom(); ?>
									</span>
								</small>
							</div>
							<div>
								<small>
									<span class="classified-in">
										<?php $this->lang('CLASSIFIED_IN') ?> : <?php $this->artCat() ?>
									</span>
									<span class="tags">
										<?php $this->lang('TAGS') ?> : <?php $this->artTags() ?>
									</span>
								</small>
							</div>
						</header>
						<?php $this->artThumbnail(); ?>
						<?php $this->artChapo(); ?>
					</article>
<?php
}
?>
